@@ -17,17 +17,16 @@ class CDVDOverlayCodecTX3G : public CDVDOverlayCodec, private CSubtitlesAdapter
 {
 public:
   CDVDOverlayCodecTX3G();
-  ~CDVDOverlayCodecTX3G() override;
+  ~CDVDOverlayCodecTX3G() override = default;
   bool Open(CDVDStreamInfo& hints, CDVDCodecOptions& options) override;
   OverlayMessage Decode(DemuxPacket* pPacket) override;
   void Reset() override;
   void Flush() override;
-  CDVDOverlay* GetOverlay() override;
+  std::shared_ptr<CDVDOverlay> GetOverlay() override;
 
   // Specialization of CSubtitlesAdapter
   void PostProcess(std::string& text) override;
 
 private:
-  void Dispose() override;
-  CDVDOverlay* m_pOverlay{nullptr};
+  std::shared_ptr<CDVDOverlay> m_pOverlay;
 };
