@@ -49,5 +49,5 @@ protected:
 private:
   CSubtitlesAdapter* m_adapter{nullptr};
   std::atomic_bool m_isInitialized{false};
-  CDVDOverlay* m_overlay{nullptr};
+  std::shared_ptr<CDVDOverlay> m_overlay;
 };
