@@ -11,11 +11,14 @@
 #include "FileItem.h"
 #include "GUIUserMessages.h"
 #include "ServiceBroker.h"
+#include "cores/playercorefactory/PlayerCoreFactory.h"
 #include "guilib/GUIComponent.h"
 #include "guilib/GUIWindowManager.h"
 #include "music/MusicUtils.h"
 #include "music/dialogs/GUIDialogMusicInfo.h"
+#include "playlists/PlayListTypes.h"
 #include "tags/MusicInfoTag.h"
+#include "utils/Variant.h"
 
 #include <utility>
 
@@ -41,24 +44,26 @@ bool CMusicInfo::Execute(const std::shared_ptr<CFileItem>& item) const
 
 bool CMusicBrowse::IsVisible(const CFileItem& item) const
 {
-  if (item.IsFileFolder(EFILEFOLDER_MASK_ONBROWSE))
-    return false; // handled by CMediaWindow
-
-  return item.m_bIsFolder && MUSIC_UTILS::IsItemPlayable(item);
+  return ((item.m_bIsFolder || item.IsFileFolder(EFILEFOLDER_MASK_ONBROWSE)) &&
+          MUSIC_UTILS::IsItemPlayable(item));
 }
 
 bool CMusicBrowse::Execute(const std::shared_ptr<CFileItem>& item) const
 {
+  // For file directory browsing, we need item's dyn path, for everything else the path.
+  const std::string path{item->IsFileFolder(EFILEFOLDER_MASK_ONBROWSE) ? item->GetDynPath()
+                                                                       : item->GetPath()};
+
   auto& windowMgr = CServiceBroker::GetGUI()->GetWindowManager();
   if (windowMgr.GetActiveWindow() == WINDOW_MUSIC_NAV)
   {
     CGUIMessage msg(GUI_MSG_NOTIFY_ALL, WINDOW_MUSIC_NAV, 0, GUI_MSG_UPDATE);
-    msg.SetStringParam(item->GetPath());
+    msg.SetStringParam(path);
     windowMgr.SendMessage(msg);
   }
   else
   {
-    windowMgr.ActivateWindow(WINDOW_MUSIC_NAV, {item->GetPath(), "return"});
+    windowMgr.ActivateWindow(WINDOW_MUSIC_NAV, {path, "return"});
   }
   return true;
 }
@@ -68,15 +73,67 @@ bool CMusicPlay::IsVisible(const CFileItem& item) const
   return MUSIC_UTILS::IsItemPlayable(item);
 }
 
+namespace
+{
+void Play(const std::shared_ptr<CFileItem>& item, const std::string& player)
+{
+  item->SetProperty("playlist_type_hint", PLAYLIST::TYPE_MUSIC);
+
+  const ContentUtils::PlayMode mode = item->GetProperty("CheckAutoPlayNextItem").asBoolean()
+                                          ? ContentUtils::PlayMode::CHECK_AUTO_PLAY_NEXT_ITEM
+                                          : ContentUtils::PlayMode::PLAY_ONLY_THIS;
+  MUSIC_UTILS::PlayItem(item, player, mode);
+}
+
+std::vector<std::string> GetPlayers(const CPlayerCoreFactory& playerCoreFactory,
+                                    const CFileItem& item)
+{
+  std::vector<std::string> players;
+  playerCoreFactory.GetPlayers(item, players);
+  return players;
+}
+
+bool CanQueue(const CFileItem& item)
+{
+  if (!item.CanQueue())
+    return false;
+
+  const int windowId = CServiceBroker::GetGUI()->GetWindowManager().GetActiveWindow();
+  if (windowId == WINDOW_MUSIC_PLAYLIST)
+    return false; // Already queued
+
+  return true;
+}
+} // unnamed namespace
+
 bool CMusicPlay::Execute(const std::shared_ptr<CFileItem>& item) const
 {
-  MUSIC_UTILS::PlayItem(item);
+  Play(item, "");
   return true;
 }
 
+bool CMusicPlayUsing::IsVisible(const CFileItem& item) const
+{
+  const CPlayerCoreFactory& playerCoreFactory{CServiceBroker::GetPlayerCoreFactory()};
+  return (GetPlayers(playerCoreFactory, item).size() > 1) && MUSIC_UTILS::IsItemPlayable(item);
+}
+
+bool CMusicPlayUsing::Execute(const std::shared_ptr<CFileItem>& item) const
+{
+  const CPlayerCoreFactory& playerCoreFactory{CServiceBroker::GetPlayerCoreFactory()};
+  const std::vector<std::string> players{GetPlayers(playerCoreFactory, *item)};
+  const std::string player{playerCoreFactory.SelectPlayerDialog(players)};
+  if (!player.empty())
+  {
+    Play(item, player);
+    return true;
+  }
+  return false;
+}
+
 bool CMusicPlayNext::IsVisible(const CFileItem& item) const
 {
-  if (!item.CanQueue())
+  if (!CanQueue(item))
     return false;
 
   return MUSIC_UTILS::IsItemPlayable(item);
@@ -90,7 +147,7 @@ bool CMusicPlayNext::Execute(const std::shared_ptr<CFileItem>& item) const
 
 bool CMusicQueue::IsVisible(const CFileItem& item) const
 {
-  if (!item.CanQueue())
+  if (!CanQueue(item))
     return false;
 
   return MUSIC_UTILS::IsItemPlayable(item);
