@@ -323,6 +323,11 @@ const std::string& CMusicInfoTag::GetStationArt() const
   return m_stationArt;
 }
 
+const std::string& CMusicInfoTag::GetSongVideoURL() const
+{
+  return m_songVideoURL;
+}
+
 void CMusicInfoTag::SetURL(const std::string& strURL)
 {
   m_strURL = strURL;
@@ -774,6 +779,11 @@ void CMusicInfoTag::SetStationArt(const std::string& strStationArt)
   m_stationArt = strStationArt;
 }
 
+void CMusicInfoTag::SetSongVideoURL(const std::string& songVideoURL)
+{
+  m_songVideoURL = songVideoURL;
+}
+
 void CMusicInfoTag::SetArtist(const CArtist& artist)
 {
   SetArtist(artist.strArtist);
@@ -882,6 +892,7 @@ void CMusicInfoTag::SetSong(const CSong& song)
   SetBitRate(song.iBitRate);
   SetSampleRate(song.iSampleRate);
   SetNoOfChannels(song.iChannels);
+  SetSongVideoURL(song.songVideoURL);
 
   if (song.replayGain.Get(ReplayGain::TRACK).Valid())
     m_replayGain.Set(ReplayGain::TRACK, song.replayGain.Get(ReplayGain::TRACK));
@@ -970,6 +981,7 @@ void CMusicInfoTag::Serialize(CVariant& value) const
   value["bitrate"] = m_bitrate;
   value["samplerate"] = m_samplerate;
   value["channels"] = m_channels;
+  value["songvideourl"] = m_songVideoURL;
 }
 
 void CMusicInfoTag::ToSortable(SortItem& sortable, Field field) const
@@ -1071,6 +1083,7 @@ void CMusicInfoTag::Archive(CArchive& ar)
     ar << m_samplerate;
     ar << m_bitrate;
     ar << m_channels;
+    ar << m_songVideoURL;
   }
   else
   {
@@ -1138,6 +1151,7 @@ void CMusicInfoTag::Archive(CArchive& ar)
     ar >> m_samplerate;
     ar >> m_bitrate;
     ar >> m_channels;
+    ar >> m_songVideoURL;
   }
 }
 
@@ -1193,6 +1207,7 @@ void CMusicInfoTag::Clear()
   m_channels = 0;
   m_stationName.clear();
   m_stationArt.clear();
+  m_songVideoURL.clear();
 }
 
 void CMusicInfoTag::AppendArtist(const std::string &artist)
