@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2018 Team Kodi
+ *  Copyright (C) 2014-2024 Team Kodi
  *  This file is part of Kodi - https://kodi.tv
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,13 +22,14 @@
 #include "input/joysticks/JoystickTranslator.h"
 #include "input/joysticks/RumbleGenerator.h"
 #include "input/joysticks/interfaces/IDriverHandler.h"
-#include "input/joysticks/keymaps/KeymapHandling.h"
+#include "input/keymaps/joysticks/KeymapHandling.h"
 #include "peripherals/Peripherals.h"
 #include "peripherals/addons/AddonButtonMap.h"
 #include "peripherals/bus/virtual/PeripheralBusAddon.h"
 #include "utils/log.h"
 
 #include <algorithm>
+#include <memory>
 #include <mutex>
 
 using namespace KODI;
@@ -38,14 +39,7 @@ using namespace PERIPHERALS;
 CPeripheralJoystick::CPeripheralJoystick(CPeripherals& manager,
                                          const PeripheralScanResult& scanResult,
                                          CPeripheralBus* bus)
-  : CPeripheral(manager, scanResult, bus),
-    m_requestedPort(JOYSTICK_PORT_UNKNOWN),
-    m_buttonCount(0),
-    m_hatCount(0),
-    m_axisCount(0),
-    m_motorCount(0),
-    m_supportsPowerOff(false),
-    m_rumbleGenerator(new CRumbleGenerator)
+  : CPeripheral(manager, scanResult, bus), m_rumbleGenerator(new CRumbleGenerator)
 {
   m_features.push_back(FEATURE_JOYSTICK);
   // FEATURE_RUMBLE conditionally added via SetMotorCount()
@@ -112,9 +106,9 @@ bool CPeripheralJoystick::InitialiseFeature(const PeripheralFeature feature)
         }
 
         // Give joystick monitor priority over default controller
-        m_appInput.reset(
-            new CKeymapHandling(this, false, m_manager.GetInputManager().KeymapEnvironment()));
-        m_joystickMonitor.reset(new CJoystickMonitor);
+        m_appInput = std::make_unique<KEYMAP::CKeymapHandling>(
+            this, false, m_manager.GetInputManager().KeymapEnvironment());
+        m_joystickMonitor = std::make_unique<CJoystickMonitor>();
         RegisterInputHandler(m_joystickMonitor.get(), false);
       }
     }
@@ -133,7 +127,7 @@ bool CPeripheralJoystick::InitialiseFeature(const PeripheralFeature feature)
 
 void CPeripheralJoystick::InitializeDeadzoneFiltering(IButtonMap& buttonMap)
 {
-  m_deadzoneFilter.reset(new CDeadzoneFilter(&buttonMap, this));
+  m_deadzoneFilter = std::make_unique<CDeadzoneFilter>(&buttonMap, this);
 }
 
 void CPeripheralJoystick::InitializeControllerProfile(IButtonMap& buttonMap)
@@ -161,23 +155,26 @@ void CPeripheralJoystick::InitializeControllerProfile(IButtonMap& buttonMap)
                          m_installTasks.end());
 
     // Install controller off-thread
-    std::future<void> installTask = std::async(std::launch::async, [this]() {
-      // Withdraw controller from queue
-      std::string controllerToInstall;
-      {
-        std::unique_lock<CCriticalSection> lock(m_controllerInstallMutex);
-        if (!m_controllersToInstall.empty())
-        {
-          controllerToInstall = m_controllersToInstall.front();
-          m_controllersToInstall.pop();
-        }
-      }
+    std::future<void> installTask =
+        std::async(std::launch::async,
+                   [this]()
+                   {
+                     // Withdraw controller from queue
+                     std::string controllerToInstall;
+                     {
+                       std::unique_lock<CCriticalSection> lock(m_controllerInstallMutex);
+                       if (!m_controllersToInstall.empty())
+                       {
+                         controllerToInstall = m_controllersToInstall.front();
+                         m_controllersToInstall.pop();
+                       }
+                     }
 
-      // Do the install
-      GAME::ControllerPtr controller = InstallAsync(controllerToInstall);
-      if (controller)
-        CPeripheral::SetControllerProfile(controller);
-    });
+                     // Do the install
+                     GAME::ControllerPtr controller = InstallAsync(controllerToInstall);
+                     if (controller)
+                       CPeripheral::SetControllerProfile(controller);
+                   });
 
     // Hold the task to prevent the destructor from completing during an install
     m_installTasks.emplace_back(std::move(installTask));
@@ -235,13 +232,12 @@ void CPeripheralJoystick::UnregisterJoystickDriverHandler(IDriverHandler* handle
   std::unique_lock<CCriticalSection> lock(m_handlerMutex);
 
   m_driverHandlers.erase(std::remove_if(m_driverHandlers.begin(), m_driverHandlers.end(),
-                                        [handler](const DriverHandler& driverHandler) {
-                                          return driverHandler.handler == handler;
-                                        }),
+                                        [handler](const DriverHandler& driverHandler)
+                                        { return driverHandler.handler == handler; }),
                          m_driverHandlers.end());
 }
 
-IKeymap* CPeripheralJoystick::GetKeymap(const std::string& controllerId)
+KEYMAP::IKeymap* CPeripheralJoystick::GetKeymap(const std::string& controllerId)
 {
   return m_appInput->GetKeymap(controllerId);
 }
