@@ -66,14 +66,14 @@ bool GetRootDirectory(bool bRadio, CFileItemList& results)
 {
   std::shared_ptr<CFileItem> item;
 
-  const std::shared_ptr<CPVRClients> clients = CServiceBroker::GetPVRManager().Clients();
+  const std::shared_ptr<const CPVRClients> clients = CServiceBroker::GetPVRManager().Clients();
 
   // EPG
   const bool bAnyClientSupportingEPG = clients->AnyClientSupportingEPG();
   if (bAnyClientSupportingEPG)
   {
-    item.reset(
-        new CFileItem(StringUtils::Format("pvr://guide/{}/", bRadio ? "radio" : "tv"), true));
+    item = std::make_shared<CFileItem>(
+        StringUtils::Format("pvr://guide/{}/", bRadio ? "radio" : "tv"), true);
     item->SetLabel(g_localizeStrings.Get(19069)); // Guide
     item->SetProperty("node.target", CWindowTranslator::TranslateWindow(bRadio ? WINDOW_RADIO_GUIDE
                                                                                : WINDOW_TV_GUIDE));
@@ -82,8 +82,8 @@ bool GetRootDirectory(bool bRadio, CFileItemList& results)
   }
 
   // Channels
-  item.reset(new CFileItem(
-      bRadio ? CPVRChannelsPath::PATH_RADIO_CHANNELS : CPVRChannelsPath::PATH_TV_CHANNELS, true));
+  item = std::make_shared<CFileItem>(
+      bRadio ? CPVRChannelsPath::PATH_RADIO_CHANNELS : CPVRChannelsPath::PATH_TV_CHANNELS, true);
   item->SetLabel(g_localizeStrings.Get(19019)); // Channels
   item->SetProperty("node.target", CWindowTranslator::TranslateWindow(bRadio ? WINDOW_RADIO_CHANNELS
                                                                              : WINDOW_TV_CHANNELS));
@@ -93,9 +93,9 @@ bool GetRootDirectory(bool bRadio, CFileItemList& results)
   // Recordings
   if (clients->AnyClientSupportingRecordings())
   {
-    item.reset(new CFileItem(bRadio ? CPVRRecordingsPath::PATH_ACTIVE_RADIO_RECORDINGS
-                                    : CPVRRecordingsPath::PATH_ACTIVE_TV_RECORDINGS,
-                             true));
+    item = std::make_shared<CFileItem>(bRadio ? CPVRRecordingsPath::PATH_ACTIVE_RADIO_RECORDINGS
+                                              : CPVRRecordingsPath::PATH_ACTIVE_TV_RECORDINGS,
+                                       true);
     item->SetLabel(g_localizeStrings.Get(19017)); // Recordings
     item->SetProperty("node.target", CWindowTranslator::TranslateWindow(
                                          bRadio ? WINDOW_RADIO_RECORDINGS : WINDOW_TV_RECORDINGS));
@@ -105,16 +105,16 @@ bool GetRootDirectory(bool bRadio, CFileItemList& results)
 
   // Timers/Timer rules
   // - always present, because Reminders are always available, no client support needed for this
-  item.reset(new CFileItem(
-      bRadio ? CPVRTimersPath::PATH_RADIO_TIMERS : CPVRTimersPath::PATH_TV_TIMERS, true));
+  item = std::make_shared<CFileItem>(
+      bRadio ? CPVRTimersPath::PATH_RADIO_TIMERS : CPVRTimersPath::PATH_TV_TIMERS, true);
   item->SetLabel(g_localizeStrings.Get(19040)); // Timers
   item->SetProperty("node.target", CWindowTranslator::TranslateWindow(bRadio ? WINDOW_RADIO_TIMERS
                                                                              : WINDOW_TV_TIMERS));
   item->SetArt("icon", "DefaultPVRTimers.png");
   results.Add(item);
 
-  item.reset(new CFileItem(
-      bRadio ? CPVRTimersPath::PATH_RADIO_TIMER_RULES : CPVRTimersPath::PATH_TV_TIMER_RULES, true));
+  item = std::make_shared<CFileItem>(
+      bRadio ? CPVRTimersPath::PATH_RADIO_TIMER_RULES : CPVRTimersPath::PATH_TV_TIMER_RULES, true);
   item->SetLabel(g_localizeStrings.Get(19138)); // Timer rules
   item->SetProperty("node.target", CWindowTranslator::TranslateWindow(
                                        bRadio ? WINDOW_RADIO_TIMER_RULES : WINDOW_TV_TIMER_RULES));
@@ -124,8 +124,8 @@ bool GetRootDirectory(bool bRadio, CFileItemList& results)
   // Search
   if (bAnyClientSupportingEPG)
   {
-    item.reset(new CFileItem(
-        bRadio ? CPVREpgSearchPath::PATH_RADIO_SEARCH : CPVREpgSearchPath::PATH_TV_SEARCH, true));
+    item = std::make_shared<CFileItem>(
+        bRadio ? CPVREpgSearchPath::PATH_RADIO_SEARCH : CPVREpgSearchPath::PATH_TV_SEARCH, true);
     item->SetLabel(g_localizeStrings.Get(137)); // Search
     item->SetProperty("node.target", CWindowTranslator::TranslateWindow(bRadio ? WINDOW_RADIO_SEARCH
                                                                                : WINDOW_TV_SEARCH));
@@ -154,17 +154,17 @@ bool CPVRGUIDirectory::GetDirectory(CFileItemList& results) const
     {
       std::shared_ptr<CFileItem> item;
 
-      item.reset(new CFileItem(base + "channels/", true));
+      item = std::make_shared<CFileItem>(base + "channels/", true);
       item->SetLabel(g_localizeStrings.Get(19019)); // Channels
       item->SetLabelPreformatted(true);
       results.Add(item);
 
-      item.reset(new CFileItem(base + "recordings/active/", true));
+      item = std::make_shared<CFileItem>(base + "recordings/active/", true);
       item->SetLabel(g_localizeStrings.Get(19017)); // Recordings
       item->SetLabelPreformatted(true);
       results.Add(item);
 
-      item.reset(new CFileItem(base + "recordings/deleted/", true));
+      item = std::make_shared<CFileItem>(base + "recordings/deleted/", true);
       item->SetLabel(g_localizeStrings.Get(19184)); // Deleted recordings
       item->SetLabelPreformatted(true);
       results.Add(item);
@@ -309,7 +309,7 @@ void GetSubDirectories(const CPVRRecordingsPath& recParentPath,
     std::shared_ptr<CFileItem> item;
     if (!results.Contains(strFilePath))
     {
-      item.reset(new CFileItem(strCurrent, true));
+      item = std::make_shared<CFileItem>(strCurrent, true);
       item->SetPath(strFilePath);
       item->SetLabel(strCurrent);
       item->SetLabelPreformatted(true);
@@ -317,10 +317,11 @@ void GetSubDirectories(const CPVRRecordingsPath& recParentPath,
       item->SetProperty("totalepisodes", 0);
       item->SetProperty("watchedepisodes", 0);
       item->SetProperty("unwatchedepisodes", 0);
+      item->SetProperty("inprogressepisodes", 0);
       item->SetProperty("sizeinbytes", UINT64_C(0));
 
       // Assume all folders are watched, we'll change the overlay later
-      item->SetOverlayImage(CGUIListItem::ICON_OVERLAY_WATCHED, false);
+      item->SetOverlayImage(CGUIListItem::ICON_OVERLAY_WATCHED);
       results.Add(item);
     }
     else
@@ -340,9 +341,10 @@ void GetSubDirectories(const CPVRRecordingsPath& recParentPath,
     {
       item->IncrementProperty("watchedepisodes", 1);
     }
-    item->SetLabel2(StringUtils::Format("{} / {}", item->GetProperty("watchedepisodes").asString(),
-                                        item->GetProperty("totalepisodes").asString()));
-
+    if (recording->GetResumePoint().IsPartWay())
+    {
+      item->IncrementProperty("inprogressepisodes", 1);
+    }
     item->IncrementProperty("sizeinbytes", recording->GetSizeInBytes());
   }
 
@@ -358,7 +360,7 @@ void GetSubDirectories(const CPVRRecordingsPath& recParentPath,
 
   // Change the watched overlay to unwatched for folders containing unwatched entries
   for (auto& item : unwatchedFolders)
-    item->SetOverlayImage(CGUIListItem::ICON_OVERLAY_UNWATCHED, false);
+    item->SetOverlayImage(CGUIListItem::ICON_OVERLAY_UNWATCHED);
 }
 
 } // unnamed namespace
@@ -410,7 +412,8 @@ bool CPVRGUIDirectory::GetRecordingsDirectory(CFileItemList& results) const
         continue;
 
       item = std::make_shared<CFileItem>(recording);
-      item->SetOverlayImage(CGUIListItem::ICON_OVERLAY_UNWATCHED, recording->GetPlayCount() > 0);
+      item->SetOverlayImage(recording->GetPlayCount() > 0 ? CGUIListItem::ICON_OVERLAY_WATCHED
+                                                          : CGUIListItem::ICON_OVERLAY_UNWATCHED);
       results.Add(item);
     }
   }
@@ -453,6 +456,109 @@ bool CPVRGUIDirectory::GetChannelGroupsDirectory(bool bRadio,
   return false;
 }
 
+namespace
+{
+std::shared_ptr<CPVRChannelGroupMember> GetLastWatchedChannelGroupMember(
+    const std::shared_ptr<CPVRChannel>& channel)
+{
+  const int lastGroupId{channel->LastWatchedGroupId()};
+  if (lastGroupId != PVR_GROUP_ID_UNNKOWN)
+  {
+    const std::shared_ptr<const CPVRChannelGroup> lastGroup{
+        CServiceBroker::GetPVRManager().ChannelGroups()->GetByIdFromAll(lastGroupId)};
+    if (lastGroup && !lastGroup->IsHidden() && !lastGroup->IsDeleted())
+      return lastGroup->GetByUniqueID(channel->StorageId());
+  }
+  return {};
+}
+
+std::shared_ptr<CPVRChannelGroupMember> GetFirstMatchingGroupMember(
+    const std::shared_ptr<CPVRChannel>& channel)
+{
+  CPVRChannelGroups* groups{
+      CServiceBroker::GetPVRManager().ChannelGroups()->Get(channel->IsRadio())};
+  if (groups)
+  {
+    const std::vector<std::shared_ptr<CPVRChannelGroup>> channelGroups{
+        groups->GetMembers(true /* exclude hidden */)};
+
+    for (const auto& channelGroup : channelGroups)
+    {
+      if (channelGroup->IsDeleted())
+        continue;
+
+      std::shared_ptr<CPVRChannelGroupMember> groupMember{
+          channelGroup->GetByUniqueID(channel->StorageId())};
+      if (groupMember)
+        return groupMember;
+    }
+  }
+  return {};
+}
+
+std::vector<std::shared_ptr<CPVRChannelGroupMember>> GetChannelGroupMembers(
+    const CPVRChannelsPath& path)
+{
+  const std::string& groupName{path.GetGroupName()};
+
+  std::shared_ptr<CPVRChannelGroup> group;
+  if (path.IsHiddenChannelGroup()) // hidden channels from the 'all channels' group
+  {
+    group = CServiceBroker::GetPVRManager().ChannelGroups()->GetGroupAll(path.IsRadio());
+  }
+  else if (groupName == "*") // all channels across all groups
+  {
+    group = CServiceBroker::GetPVRManager().ChannelGroups()->GetGroupAll(path.IsRadio());
+    if (group)
+    {
+      std::vector<std::shared_ptr<CPVRChannelGroupMember>> result;
+
+      const std::vector<std::shared_ptr<CPVRChannelGroupMember>> allGroupMembers{
+          group->GetMembers(CPVRChannelGroup::Include::ONLY_VISIBLE)};
+      for (const auto& allGroupMember : allGroupMembers)
+      {
+        std::shared_ptr<CPVRChannelGroupMember> member{
+            GetLastWatchedChannelGroupMember(allGroupMember->Channel())};
+        if (member)
+        {
+          result.emplace_back(member);
+          continue; // Process next 'All channels' group member.
+        }
+
+        if (group->IsHidden())
+        {
+          // Very special case. 'All channels' group is hidden. Let's see what we get iterating all
+          // non-hidden / non-deleted groups. We must not return any 'All channels' group members,
+          // because their path is invalid (it contains the group).
+          member = GetFirstMatchingGroupMember(allGroupMember->Channel());
+          if (member)
+            result.emplace_back(member);
+        }
+        else
+        {
+          // Use the 'All channels' group member.
+          result.emplace_back(allGroupMember);
+        }
+      }
+      return result;
+    }
+  }
+  else
+  {
+    group = CServiceBroker::GetPVRManager()
+                .ChannelGroups()
+                ->Get(path.IsRadio())
+                ->GetByName(groupName, path.GetGroupClientID());
+  }
+
+  if (group)
+    return group->GetMembers(CPVRChannelGroup::Include::ALL);
+
+  CLog::LogF(LOGERROR, "Unable to obtain members for channel group '{}'", groupName);
+  return {};
+}
+} // unnamed namespace
+
 bool CPVRGUIDirectory::GetChannelsDirectory(CFileItemList& results) const
 {
   const CPVRChannelsPath path(m_url.GetWithoutOptions());
@@ -463,13 +569,13 @@ bool CPVRGUIDirectory::GetChannelsDirectory(CFileItemList& results) const
       std::shared_ptr<CFileItem> item;
 
       // all tv channels
-      item.reset(new CFileItem(CPVRChannelsPath::PATH_TV_CHANNELS, true));
+      item = std::make_shared<CFileItem>(CPVRChannelsPath::PATH_TV_CHANNELS, true);
       item->SetLabel(g_localizeStrings.Get(19020)); // TV
       item->SetLabelPreformatted(true);
       results.Add(item);
 
       // all radio channels
-      item.reset(new CFileItem(CPVRChannelsPath::PATH_RADIO_CHANNELS, true));
+      item = std::make_shared<CFileItem>(CPVRChannelsPath::PATH_RADIO_CHANNELS, true);
       item->SetLabel(g_localizeStrings.Get(19021)); // Radio
       item->SetLabelPreformatted(true);
       results.Add(item);
@@ -482,46 +588,20 @@ bool CPVRGUIDirectory::GetChannelsDirectory(CFileItemList& results) const
     }
     else if (path.IsChannelGroup())
     {
-      const std::string& strGroupName = path.GetGroupName();
-      bool bShowHiddenChannels = path.IsHiddenChannelGroup();
-
-      std::shared_ptr<CPVRChannelGroup> group;
-      if (bShowHiddenChannels || strGroupName == "*") // all channels
+      const bool playedOnly{(m_url.HasOption("view") && (m_url.GetOption("view") == "lastplayed"))};
+      const bool showHiddenChannels{path.IsHiddenChannelGroup()};
+      const std::vector<std::shared_ptr<CPVRChannelGroupMember>> groupMembers{
+          GetChannelGroupMembers(path)};
+      for (const auto& groupMember : groupMembers)
       {
-        group = CServiceBroker::GetPVRManager().ChannelGroups()->GetGroupAll(path.IsRadio());
+        if (showHiddenChannels != groupMember->Channel()->IsHidden())
+          continue;
+
+        if (playedOnly && !groupMember->Channel()->LastWatched())
+          continue;
+
+        results.Add(std::make_shared<CFileItem>(groupMember));
       }
-      else
-      {
-        group = CServiceBroker::GetPVRManager()
-                    .ChannelGroups()
-                    ->Get(path.IsRadio())
-                    ->GetByName(strGroupName);
-      }
-
-      if (group)
-      {
-        const bool playedOnly =
-            (m_url.HasOption("view") && (m_url.GetOption("view") == "lastplayed"));
-
-        const std::vector<std::shared_ptr<CPVRChannelGroupMember>> groupMembers =
-            group->GetMembers();
-        for (const auto& groupMember : groupMembers)
-        {
-          if (bShowHiddenChannels != groupMember->Channel()->IsHidden())
-            continue;
-
-          if (playedOnly && !groupMember->Channel()->LastWatched())
-            continue;
-
-          results.Add(std::make_shared<CFileItem>(groupMember));
-        }
-      }
-      else
-      {
-        CLog::LogF(LOGERROR, "Unable to obtain members of channel group '{}'", strGroupName);
-        return false;
-      }
-
       return true;
     }
   }
@@ -570,7 +650,7 @@ bool GetTimersSubDirectory(const CPVRTimersPath& path,
     if ((timer->IsRadio() == bRadio) && timer->HasParent() && (timer->ClientID() == iClientId) &&
         (timer->ParentClientIndex() == iParentId) && (!bHideDisabled || !timer->IsDisabled()))
     {
-      item.reset(new CFileItem(timer));
+      item = std::make_shared<CFileItem>(timer);
       const CPVRTimersPath timersPath(path.GetPath(), timer->ClientID(), timer->ClientIndex());
       item->SetPath(timersPath.GetPath());
       results.Add(item);
