@@ -26,6 +26,11 @@ class CVideoSettings;
 class CGUIDialogProgress;
 class CGUIDialogProgressBarHandle;
 
+struct VideoAssetInfo;
+
+enum class VideoAssetTypeOwner;
+enum class VideoAssetType;
+
 namespace dbiplus
 {
   class field_value;
@@ -93,6 +98,13 @@ enum VideoDbDetails
 #define VIDEODB_DETAILS_MOVIE_RATING_TYPE       VIDEODB_MAX_COLUMNS + 17
 #define VIDEODB_DETAILS_MOVIE_UNIQUEID_VALUE    VIDEODB_MAX_COLUMNS + 18
 #define VIDEODB_DETAILS_MOVIE_UNIQUEID_TYPE     VIDEODB_MAX_COLUMNS + 19
+#define VIDEODB_DETAILS_MOVIE_HASVERSIONS       VIDEODB_MAX_COLUMNS + 20
+#define VIDEODB_DETAILS_MOVIE_HASEXTRAS VIDEODB_MAX_COLUMNS + 21
+#define VIDEODB_DETAILS_MOVIE_ISDEFAULTVERSION VIDEODB_MAX_COLUMNS + 22
+#define VIDEODB_DETAILS_MOVIE_VERSION_FILEID VIDEODB_MAX_COLUMNS + 23
+#define VIDEODB_DETAILS_MOVIE_VERSION_TYPEID VIDEODB_MAX_COLUMNS + 24
+#define VIDEODB_DETAILS_MOVIE_VERSION_TYPENAME VIDEODB_MAX_COLUMNS + 25
+#define VIDEODB_DETAILS_MOVIE_VERSION_ITEMTYPE VIDEODB_MAX_COLUMNS + 26
 
 #define VIDEODB_DETAILS_EPISODE_TVSHOW_ID       VIDEODB_MAX_COLUMNS + 2
 #define VIDEODB_DETAILS_EPISODE_USER_RATING     VIDEODB_MAX_COLUMNS + 3
@@ -130,6 +142,7 @@ enum VideoDbDetails
 #define VIDEODB_DETAILS_TVSHOW_RATING_TYPE      VIDEODB_MAX_COLUMNS + 12
 #define VIDEODB_DETAILS_TVSHOW_UNIQUEID_VALUE   VIDEODB_MAX_COLUMNS + 13
 #define VIDEODB_DETAILS_TVSHOW_UNIQUEID_TYPE    VIDEODB_MAX_COLUMNS + 14
+#define VIDEODB_DETAILS_TVSHOW_NUM_INPROGRESS VIDEODB_MAX_COLUMNS + 15
 
 #define VIDEODB_DETAILS_MUSICVIDEO_USER_RATING  VIDEODB_MAX_COLUMNS + 2
 #define VIDEODB_DETAILS_MUSICVIDEO_PREMIERED    VIDEODB_MAX_COLUMNS + 3
@@ -290,6 +303,7 @@ typedef enum // this enum MUST match the offset struct further down!! and make s
   VIDEODB_ID_SEASON_EPISODES_TOTAL = 12,
   VIDEODB_ID_SEASON_EPISODES_WATCHED = 13,
   VIDEODB_ID_SEASON_PREMIERED = 14,
+  VIDEODB_ID_SEASON_EPISODES_INPROGRESS = 15,
   VIDEODB_ID_SEASON_MAX
 } VIDEODB_SEASON_IDS;
 
@@ -387,6 +401,18 @@ const struct SDbTableOffsets DbMusicVideoOffsets[] =
   { VIDEODB_TYPE_INT, my_offsetof(CVideoInfoTag,m_iIdUniqueID)}
 };
 
+enum class ArtFallbackOptions
+{
+  NONE,
+  PARENT
+};
+
+enum class DeleteMovieCascadeAction
+{
+  DEFAULT_VERSION,
+  ALL_ASSETS
+};
+
 #define COMPARE_PERCENTAGE     0.90f // 90%
 #define COMPARE_PERCENTAGE_MIN 0.50f // 50%
 
@@ -511,8 +537,13 @@ public:
   int GetSeasonForEpisode(int idEpisode);
 
   bool LoadVideoInfo(const std::string& strFilenameAndPath, CVideoInfoTag& details, int getDetails = VideoDbDetailsAll);
-  bool GetMovieInfo(const std::string& strFilenameAndPath, CVideoInfoTag& details, int idMovie = -1, int getDetails = VideoDbDetailsAll);
+  bool GetMovieInfo(const std::string& strFilenameAndPath,
+                    CVideoInfoTag& details,
+                    int idMovie = -1,
+                    int idVersion = -1,
+                    int getDetails = VideoDbDetailsAll);
   bool GetTvShowInfo(const std::string& strPath, CVideoInfoTag& details, int idTvShow = -1, CFileItem* item = NULL, int getDetails = VideoDbDetailsAll);
+  bool GetSeasonInfo(const std::string& path, int season, CVideoInfoTag& details, CFileItem* item);
   bool GetSeasonInfo(int idSeason, CVideoInfoTag& details, CFileItem* item);
   bool GetSeasonInfo(int idSeason, CVideoInfoTag& details, bool allDetails = true);
   bool GetEpisodeBasicInfo(const std::string& strFilenameAndPath, CVideoInfoTag& details, int idEpisode  = -1);
@@ -569,7 +600,9 @@ public:
 
   int UpdateDetailsForMovie(int idMovie, CVideoInfoTag& details, const std::map<std::string, std::string> &artwork, const std::set<std::string> &updatedDetails);
 
-  void DeleteMovie(int idMovie, bool bKeepId = false);
+  void DeleteMovie(int idMovie,
+                   bool bKeepId = false,
+                   DeleteMovieCascadeAction action = DeleteMovieCascadeAction::ALL_ASSETS);
   void DeleteTvShow(int idTvShow, bool bKeepId = false);
   void DeleteTvShow(const std::string& strPath);
   void DeleteSeason(int idSeason, bool bKeepId = false);
@@ -803,6 +836,7 @@ public:
                   VideoDbContentType idContent = VideoDbContentType::UNKNOWN,
                   const Filter& filter = Filter(),
                   bool countOnly = false);
+
   bool GetMusicVideoAlbumsNav(const std::string& strBaseDir, CFileItemList& items, int idArtist, const Filter &filter = Filter(), bool countOnly = false);
 
   bool GetMoviesNav(const std::string& strBaseDir, CFileItemList& items, int idGenre=-1, int idYear=-1, int idActor=-1, int idDirector=-1, int idStudio=-1, int idCountry=-1, int idSet=-1, int idTag=-1, const SortDescription &sortDescription = SortDescription(), int getDetails = VideoDbDetailsNone);
@@ -928,6 +962,19 @@ public:
   void SetArtForItem(int mediaId, const MediaType &mediaType, const std::map<std::string, std::string> &art);
   bool GetArtForItem(int mediaId, const MediaType &mediaType, std::map<std::string, std::string> &art);
   std::string GetArtForItem(int mediaId, const MediaType &mediaType, const std::string &artType);
+
+  /*!
+   * \brief Retrieve all art for the given video asset, with optional fallback to the art of the
+   * parent/owner of the asset
+   * \param assetId id of the file of the asset
+   * \param fallback optionally request fallback to the art of the parent/owner for each art type
+     that is not defined for the asset
+   * \param art collection of the retrieved art
+   * \return 
+  */
+  bool GetArtForAsset(int assetId,
+                      ArtFallbackOptions fallback,
+                      std::map<std::string, std::string>& art);
   bool HasArtForItem(int mediaId, const MediaType &mediaType);
   bool RemoveArtForItem(int mediaId, const MediaType &mediaType, const std::string &artType);
   bool RemoveArtForItem(int mediaId, const MediaType &mediaType, const std::set<std::string> &artTypes);
@@ -976,17 +1023,79 @@ public:
   \return The dbId of the season.
   */
   int AddSeason(int showID, int season, const std::string& name = "");
-  int AddSet(const std::string& strSet, const std::string& strOverview = "");
+  int AddSet(const std::string& strSet,
+             const std::string& strOverview = "",
+             const bool updateOverview = true);
   void ClearMovieSet(int idMovie);
   void SetMovieSet(int idMovie, int idSet);
   bool SetVideoUserRating(int dbId, int rating, const MediaType& mediaType);
   bool GetUseAllExternalAudioForVideo(const std::string& videoPath);
 
+  std::string GetSetByNameLike(const std::string& nameLike) const;
+
+  std::string GetVideoItemTitle(VideoDbContentType itemType, int dbId);
+  std::string GetVideoVersionById(int id);
+  void GetVideoVersions(VideoDbContentType itemType,
+                        int dbId,
+                        CFileItemList& items,
+                        VideoAssetType videoAssetType);
+  void GetDefaultVideoVersion(VideoDbContentType itemType, int dbId, CFileItem& item);
+
+  /*!
+   * \brief Remove a video from the library and transfer all of its assets to another video of the
+   * same type.
+   * \param itemType Type of the video being converted
+   * \param dbIdSource id of the video being converted
+   * \param dbIdTarget id that the video will be attached to
+   * \param idVideoVersion new versiontype of the default version of the video
+   * \param assetType new asset type of the default version of the video
+   * \return true for success, false otherwise
+   */
+  bool ConvertVideoToVersion(VideoDbContentType itemType,
+                             int dbIdSource,
+                             int dbIdTarget,
+                             int idVideoVersion,
+                             VideoAssetType assetType);
+  void SetDefaultVideoVersion(VideoDbContentType itemType, int dbId, int idFile);
+  void SetVideoVersion(int idFile, int idVideoVersion);
+  int AddVideoVersionType(const std::string& typeVideoVersion,
+                          VideoAssetTypeOwner owner,
+                          VideoAssetType assetType);
+  void AddVideoAsset(VideoDbContentType itemType,
+                     int dbId,
+                     int idVideoVersion,
+                     VideoAssetType videoAssetType,
+                     CFileItem& item);
+  bool DeleteVideoAsset(int idFile);
+  bool IsDefaultVideoVersion(int idFile);
+  bool GetVideoVersionTypes(VideoDbContentType idContent,
+                            VideoAssetType asset,
+                            CFileItemList& items);
+  void SetVideoVersionDefaultArt(int dbId, int idFrom, VideoDbContentType type);
+  void InitializeVideoVersionTypeTable(int schemaVersion);
+  void UpdateVideoVersionTypeTable();
+  bool GetVideoVersionsNav(const std::string& strBaseDir,
+                           CFileItemList& items,
+                           VideoDbContentType idContent = VideoDbContentType::UNKNOWN,
+                           const Filter& filter = Filter());
+  VideoAssetInfo GetVideoVersionInfo(const std::string& filenameAndPath);
+  bool GetAssetsForVideo(VideoDbContentType itemType,
+                         int mediaId,
+                         VideoAssetType assetType,
+                         CFileItemList& items);
+  bool GetDefaultVersionForVideo(VideoDbContentType itemType, int mediaId, CFileItem& item);
+  bool UpdateAssetsOwner(const std::string& mediaType, int dbIdSource, int dbIdTarget);
+
+  int GetMovieId(const std::string& strFilenameAndPath);
+  std::string GetMovieTitle(int idMovie);
+  void GetSameVideoItems(const CFileItem& item, CFileItemList& items);
+  int GetFileIdByMovie(int idMovie);
+  std::string GetFileBasePathById(int idFile);
+
 protected:
   int AddNewMovie(CVideoInfoTag& details);
   int AddNewMusicVideo(CVideoInfoTag& details);
 
-  int GetMovieId(const std::string& strFilenameAndPath);
   int GetMusicVideoId(const std::string& strFilenameAndPath);
 
   /*! \brief Get the id of this fileitem
@@ -1151,4 +1260,6 @@ private:
   static void AnnounceUpdate(const std::string& content, int id);
 
   static CDateTime GetDateAdded(const std::string& filename, CDateTime dateAdded = CDateTime());
+
+  bool FillMovieItem(std::unique_ptr<dbiplus::Dataset>& dataset, int movieId, CFileItem& item);
 };
