@@ -35,7 +35,6 @@
 #include "utils/Variant.h"
 #include "utils/log.h"
 #include "video/VideoDatabase.h"
-#include "video/VideoThumbLoader.h"
 #include "view/ViewState.h"
 
 #include <mutex>
@@ -51,12 +50,10 @@
 #define CONTROL_THUMBS                11
 
 CGUIDialogVideoBookmarks::CGUIDialogVideoBookmarks()
-    : CGUIDialog(WINDOW_DIALOG_VIDEO_BOOKMARKS, "VideoOSDBookmarks.xml"),
-    CJobQueue(false, 1, CJob::PRIORITY_NORMAL)
+  : CGUIDialog(WINDOW_DIALOG_VIDEO_BOOKMARKS, "VideoOSDBookmarks.xml")
 {
   m_vecItems = new CFileItemList;
   m_loadType = LOAD_EVERY_TIME;
-  m_jobsStarted = 0;
 }
 
 CGUIDialogVideoBookmarks::~CGUIDialogVideoBookmarks()
@@ -137,9 +134,6 @@ bool CGUIDialogVideoBookmarks::OnMessage(CGUIMessage& message)
       case 0:
         OnRefreshList();
         break;
-      case 1:
-        UpdateItem(message.GetParam2());
-        break;
       default:
         break;
       }
@@ -191,10 +185,7 @@ void CGUIDialogVideoBookmarks::Delete(int item)
   {
     CVideoDatabase videoDatabase;
     videoDatabase.Open();
-    std::string path(g_application.CurrentFile());
-    if (g_application.CurrentFileItem().HasProperty("original_listitem_url") &&
-       !URIUtils::IsVideoDb(g_application.CurrentFileItem().GetProperty("original_listitem_url").asString()))
-      path = g_application.CurrentFileItem().GetProperty("original_listitem_url").asString();
+    const std::string path{g_application.CurrentFileItem().GetDynPath()};
     videoDatabase.ClearBookMarkOfFile(path, m_bookmarks[item], m_bookmarks[item].type);
     videoDatabase.Close();
     CUtil::DeleteVideoDatabaseDirectoryCache();
@@ -202,40 +193,13 @@ void CGUIDialogVideoBookmarks::Delete(int item)
   Update();
 }
 
-void CGUIDialogVideoBookmarks::UpdateItem(unsigned int chapterIdx)
-{
-  std::unique_lock<CCriticalSection> lock(m_refreshSection);
-
-  int itemPos = 0;
-  for (const auto& item : *m_vecItems)
-  {
-    if (chapterIdx == item->GetProperty("chapter").asInteger())
-      break;
-    itemPos++;
-  }
-
-  if (itemPos < m_vecItems->Size())
-  {
-    std::string time = StringUtils::Format("chapter://{}/{}", m_filePath, chapterIdx);
-    std::string cachefile = CServiceBroker::GetTextureCache()->GetCachedPath(
-        CServiceBroker::GetTextureCache()->GetCacheFile(time) + ".jpg");
-    if (CFileUtils::Exists(cachefile))
-    {
-      (*m_vecItems)[itemPos]->SetArt("thumb", cachefile);
-    }
-  }
-}
-
 void CGUIDialogVideoBookmarks::OnRefreshList()
 {
   m_bookmarks.clear();
   std::vector<CFileItemPtr> items;
 
   // open the d/b and retrieve the bookmarks for the current movie
-  m_filePath = g_application.CurrentFile();
-  if (g_application.CurrentFileItem().HasProperty("original_listitem_url") &&
-     !URIUtils::IsVideoDb(g_application.CurrentFileItem().GetProperty("original_listitem_url").asString()))
-     m_filePath = g_application.CurrentFileItem().GetProperty("original_listitem_url").asString();
+  m_filePath = g_application.CurrentFileItem().GetDynPath();
 
   CVideoDatabase videoDatabase;
   videoDatabase.Open();
@@ -285,18 +249,11 @@ void CGUIDialogVideoBookmarks::OnRefreshList()
     CFileItemPtr item(new CFileItem(chapterName));
     item->SetLabel2(time);
 
-    std::string chapterPath = StringUtils::Format("chapter://{}/{}", m_filePath, i);
-    std::string cachefile = CServiceBroker::GetTextureCache()->GetCachedPath(
-        CServiceBroker::GetTextureCache()->GetCacheFile(chapterPath) + ".jpg");
-    if (CFileUtils::Exists(cachefile))
-      item->SetArt("thumb", cachefile);
-    else if (i > m_jobsStarted && CServiceBroker::GetSettingsComponent()->GetSettings()->GetBool(CSettings::SETTING_MYVIDEOS_EXTRACTCHAPTERTHUMBS))
+    if (CServiceBroker::GetSettingsComponent()->GetSettings()->GetBool(
+            CSettings::SETTING_MYVIDEOS_EXTRACTCHAPTERTHUMBS))
     {
-      CFileItem item(m_filePath, false);
-      CJob* job = new CThumbExtractor(item, m_filePath, true, chapterPath, pos * 1000, false);
-      AddJob(job);
-      m_mapJobsChapter[job] = i;
-      m_jobsStarted++;
+      std::string chapterPath = StringUtils::Format("chapter://{}/{}", m_filePath, i);
+      item->SetArt("thumb", chapterPath);
     }
 
     item->SetProperty("chapter", i);
@@ -388,10 +345,7 @@ void CGUIDialogVideoBookmarks::ClearBookmarks()
 {
   CVideoDatabase videoDatabase;
   videoDatabase.Open();
-  std::string path = g_application.CurrentFile();
-  if (g_application.CurrentFileItem().HasProperty("original_listitem_url") &&
-     !URIUtils::IsVideoDb(g_application.CurrentFileItem().GetProperty("original_listitem_url").asString()))
-    path = g_application.CurrentFileItem().GetProperty("original_listitem_url").asString();
+  const std::string path{g_application.CurrentFileItem().GetDynPath()};
   videoDatabase.ClearBookMarksOfFile(path, CBookmark::STANDARD);
   videoDatabase.ClearBookMarksOfFile(path, CBookmark::RESUME);
   videoDatabase.ClearBookMarksOfFile(path, CBookmark::EPISODE);
@@ -462,10 +416,7 @@ bool CGUIDialogVideoBookmarks::AddBookmark(CVideoInfoTag* tag)
     videoDatabase.AddBookMarkForEpisode(*tag, bookmark);
   else
   {
-    std::string path = g_application.CurrentFile();
-    if (g_application.CurrentFileItem().HasProperty("original_listitem_url") &&
-       !URIUtils::IsVideoDb(g_application.CurrentFileItem().GetProperty("original_listitem_url").asString()))
-      path = g_application.CurrentFileItem().GetProperty("original_listitem_url").asString();
+    const std::string path{g_application.CurrentFileItem().GetDynPath()};
     videoDatabase.AddBookMarkToFile(path, bookmark, CBookmark::STANDARD);
   }
   videoDatabase.Close();
@@ -478,16 +429,11 @@ void CGUIDialogVideoBookmarks::OnWindowLoaded()
   m_viewControl.Reset();
   m_viewControl.SetParentWindow(GetID());
   m_viewControl.AddView(GetControl(CONTROL_THUMBS));
-  m_jobsStarted = 0;
-  m_mapJobsChapter.clear();
   m_vecItems->Clear();
 }
 
 void CGUIDialogVideoBookmarks::OnWindowUnload()
 {
-  //stop running thumb extraction jobs
-  CancelJobs();
-  m_mapJobsChapter.clear();
   m_vecItems->Clear();
   CGUIDialog::OnWindowUnload();
   m_viewControl.Reset();
@@ -571,20 +517,3 @@ bool CGUIDialogVideoBookmarks::OnAddEpisodeBookmark()
   }
   return bReturn;
 }
-
-void CGUIDialogVideoBookmarks::OnJobComplete(unsigned int jobID,
-                                             bool success, CJob* job)
-{
-  if (success && IsActive())
-  {
-    MAPJOBSCHAPS::iterator iter = m_mapJobsChapter.find(job);
-    if (iter != m_mapJobsChapter.end())
-    {
-      unsigned int chapterIdx = (*iter).second;
-      CGUIMessage m(GUI_MSG_REFRESH_LIST, GetID(), 0, 1, chapterIdx);
-      CServiceBroker::GetAppMessenger()->SendGUIMessage(m);
-      m_mapJobsChapter.erase(iter);
-    }
-  }
-  CJobQueue::OnJobComplete(jobID, success, job);
-}
